@@ -1,7 +1,7 @@
-from asyncio import ensure_future, Task, sleep, get_event_loop
-from typing import Dict, Coroutine, Optional
+from asyncio import ensure_future, Task, sleep, get_event_loop, Future
+from typing import Dict, Coroutine, Optional, Tuple
 
-__all__ = ('active_tasks', 'add_task', 'get_task', 'task_running', 'stop_task', 'task_exist')
+__all__ = ('active_tasks', 'add_task', 'get_task', 'task_running', 'stop_task', 'task_exist', 'stop_all_tasks', 'add_nameless_task')
 
 active_tasks: Dict[str, Task] = {}
 
@@ -10,6 +10,18 @@ def add_task(name: str, coro: Coroutine):
     active_tasks[name.lower()] = ensure_future(coro)
 
 
+nameless_task_counter = 0
+
+
+def add_nameless_task(coro: Coroutine) -> Tuple[str, Future]:
+    global nameless_task_counter
+    nameless_task_name = f'nameless_task_{nameless_task_counter}'
+    nameless_task_counter += 1
+    future = ensure_future(coro)
+    active_tasks[nameless_task_name] = future
+    return nameless_task_name, future
+
+
 def get_task(name: str) -> Optional[Task]:
     return active_tasks.get(name.lower())
 
@@ -18,6 +30,11 @@ def task_exist(name: str):
     return name.lower() in active_tasks
 
 
+def stop_all_tasks():
+    for task in active_tasks.values():
+        task.cancel()
+
+
 def stop_task(name: str) -> bool:
     """stops a task, returns if it was successful"""
     name = name.lower()
